CancelableCompleter<T> class

A completer for a CancelableOperation.

Constructors

CancelableCompleter({FutureOr onCancel()?})
Creates a new completer for a CancelableOperation.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isCanceled → bool
Whether the completer was canceled before the result was ready.
no setter
isCompleted → bool
Whether the complete or completeError have been called.
no setter
operation → CancelableOperation<T>
The operation controlled by this completer.
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

complete([FutureOr<T>? value]) → void
Completes operation with value.
completeError(Object error, [StackTrace? stackTrace]) → void
Completes operation with error and stackTrace.
completeOperation(CancelableOperation<T> result, {bool propagateCancel = true}) → void
Makes this CancelableCompleter.operation complete with the same result as result.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited